@@ -1,8 +1,8 @@
-package Search::Elasticsearch::Client::2_0::Async::Bulk;
-$Search::Elasticsearch::Client::2_0::Async::Bulk::VERSION = '6.80_01'; # TRIAL
+package Search::Elasticsearch::Client::5_0::Async::Bulk;
+$Search::Elasticsearch::Client::5_0::Async::Bulk::VERSION = '6.80_01'; # TRIAL
 
-$Search::Elasticsearch::Client::2_0::Async::Bulk::VERSION = '6.8001';use Moo;
-with 'Search::Elasticsearch::Client::2_0::Role::Bulk',
+$Search::Elasticsearch::Client::5_0::Async::Bulk::VERSION = '6.8001';use Moo;
+with 'Search::Elasticsearch::Client::5_0::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Async';
 
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -112,91 +112,9 @@ sub flush {
     return $promise;
 }
 
-#===================================
-sub reindex {
-#===================================
-    my ( $self, $params ) = parse_params(@_);
-
-    my $src = $params->{source}
-        or throw( 'Param', "Missing required param <source>" );
-
-    my $transform = $self->_doc_transformer($params);
-
-    if ( ref $src eq 'HASH' ) {
-        $src = $self->_hash_to_scroll( {%$src}, $transform );
-    }
-    elsif ( blessed($src) && $src->isa('Search::Elasticsearch::Client::2_0::Scroll') ) {
-        my $scroll = $src;
-        $src = sub {
-            $scroll->refill_buffer;
-            $scroll->drain_buffer;
-        };
-    }
-
-    my $promise;
-
-    # async scroll
-    if ( blessed($src) && $src->isa('Search::Elasticsearch::Client::2_0::Async::Scroll') ) {
-        $promise = $src->start;
-    }
-    else {
-
-        my $deferred = deferred;
-        my $weak_cb;
-        my $cb = sub {
-            my @docs = grep {defined} $src->();
-            return $deferred->resolve
-                unless @docs;
-            $self->index( grep {$_} map { $transform->($_) } @docs )
-                ->done( $weak_cb, sub { $deferred->reject(@_) } );
-        };
-        weaken( $weak_cb = $cb );
-        $promise = $deferred->promise;
-        $cb->();
-    }
-
-    $promise->finally( sub { $self->flush } );
-}
-
-#===================================
-sub _hash_to_scroll {
-#===================================
-    my ( $self, $src, $transform ) = @_;
-
-    my $scroll;
-    my $i          = 1;
-    my $on_results = sub {
-        my @docs;
-        while (@_) {
-            my $doc = $transform->( shift() ) or next;
-            push @docs, $doc;
-        }
-        return unless @docs;
-
-        $self->index(@docs)->catch( sub { $scroll->finish } );
-    };
-
-    my $on_start;
-    if ( $self->verbose ) {
-        $on_start = sub {
-            $scroll = shift;
-            print "Reindexing " . $scroll->total . " docs\n";
-        };
-    }
-    my $es = delete $src->{es} || $self->es;
-    return $scroll = $es->scroll_helper(
-        search_type => 'scan',
-        size        => 500,
-        %$src,
-        on_results => $on_results,
-        on_start   => $on_start,
-    );
-
-}
-
 1;
 
-# ABSTRACT: A helper module for the Bulk API and for reindexing
+# ABSTRACT: A helper module for the Bulk API
 
 __END__
 
@@ -206,7 +124,7 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Async::Bulk - A helper module for the Bulk API and for reindexing
+Search::Elasticsearch::Client::5_0::Async::Bulk - A helper module for the Bulk API
 
 =head1 VERSION
 
@@ -243,29 +161,20 @@ version 6.80_01
     # Manual flush
     $promise = $bulk->flush;
 
-    # Reindex docs:
-    $bulk = $es->bulk_helper(
-        index   => 'new_index',
-        verbose => 1
-    );
-
-    $promise = $bulk->reindex( source => { index => 'old_index' });
-
 =head1 DESCRIPTION
 
-This module provides an async wrapper for the L<Search::Elasticsearch::Client::2_0::Direct/bulk()>
+This module provides an async wrapper for the L<Search::Elasticsearch::Client::5_0::Direct/bulk()>
 method which makes it easier to run multiple create, index, update or delete
-actions in a single request. It also provides a simple interface
-for L<reindexing documents|/REINDEXING DOCUMENTS>.
+actions in a single request.
 
-The L<Search::Elasticsearch::Client::2_0::Async::Bulk> module acts as a queue, buffering up actions
+The L<Search::Elasticsearch::Client::5_0::Async::Bulk> module acts as a queue, buffering up actions
 until it reaches a maximum count of actions, or a maximum size of JSON request
 body, at which point it issues a C<bulk()> request.
 
 Once you have finished adding actions, call L</flush()> to force the final
 C<bulk()> request on the items left in the queue.
 
-This class does L<Search::Elasticsearch::Client::2_0::Role::Bulk> and
+This class does L<Search::Elasticsearch::Client::5_0::Role::Bulk> and
 L<Search::Elasticsearch::Role::Is_Async>.
 
 =head1 CREATING A NEW INSTANCE
@@ -291,13 +200,13 @@ L<Search::Elasticsearch::Role::Is_Async>.
 
     );
 
-The C<bulk_helper> method loads L<Search::Elasticsearch::Client::2_0::Async::Bulk>,
+The C<bulk_helper> method loads L<Search::Elasticsearch::Client::5_0::Async::Bulk>,
 calls L</new()> with the specified parameters and returns a new C<$bulk> object.
 
 The C<index> and C<type> parameters provide default values for
 C<index> and C<type>, which can be overridden in each action.
 You can also pass any other values which are accepted
-by the L<bulk()|Search::Elasticsearch::Client::2_0::Direct/bulk()> method.
+by the L<bulk()|Search::Elasticsearch::Client::5_0::Direct/bulk()> method.
 
 See L</flush()> for more information about the other parameters.
 
@@ -308,7 +217,7 @@ See L</flush()> for more information about the other parameters.
     $promise = $bulk->flush;
 
 The C<flush()> method sends all buffered actions to Elasticsearch using
-a L<bulk()|Search::Elasticsearch::Client::2_0::Direct/bulk()> request and returns
+a L<bulk()|Search::Elasticsearch::Client::5_0::Direct/bulk()> request and returns
 a L<Promise>, which is rejected if the bulk request fails or if any of
 the C<on_success>, C<on_error> or C<on_conflict> callbacks throws an
 exception, otherwise it is resolved with the items that have been flushed.
@@ -497,8 +406,8 @@ See the individual helper methods below for details.
 B<Note:> Parameters like C<index> or C<type> can be specified as C<index> or as
 C<_index>, so the following two lines are equivalent:
 
-    index => { index  => 'index', type  => 'type', id  => 1, source  => {...}},
-    index => { _index => 'index', _type => 'type', _id => 1, _source => {...}},
+    index => { index  => 'index', type  => 'type', id  => 1, source => {...}},
+    index => { _index => 'index', _type => 'type', _id => 1, source => {...}},
 
 B<Note:> The C<index> and C<type> parameters can be specified in the
 params for any action, but if not specified, will default to the C<index>
@@ -514,7 +423,7 @@ they must be specified either in L</new()> or in every action.
     );
 
 The C<create()> helper method allows you to add multiple C<create> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::2_0::Direct/create()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/create()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -540,7 +449,7 @@ you can just pass the individual document bodies.
     );
 
 The C<index()> helper method allows you to add multiple C<index> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::2_0::Direct/index()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/index()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -553,7 +462,7 @@ parameter, instead of as C<body>.
     );
 
 The C<delete()> helper method allows you to add multiple C<delete> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::2_0::Direct/delete()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/delete()>.
 
 =head2 C<delete_ids()>
 
@@ -578,164 +487,11 @@ In this case, all you have to do is to pass in a list of IDs.
     );
 
 The C<update()> helper method allows you to add multiple C<update> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::2_0::Direct/update()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/update()>.
 An update can either use a I<partial doc> which gets merged with an existing
 doc (example 1 above), or can use a C<script> to update an existing doc
 (example 2 above). More information on C<script> can be found here:
-L<Search::Elasticsearch::Client::2_0::Direct/update()>.
-
-=head1 REINDEXING DOCUMENTS
-
-A common use case for bulk indexing is to reindex a whole index when
-changing the type mappings or analysis chain. This typically
-combines bulk indexing with L<scrolled searches|Search::Elasticsearch::Client::2_0::Scroll>:
-the scrolled search pulls all of the data from the source index, and
-the bulk indexer indexes the data into the new index.
-
-=head2 C<reindex()>
-
-    $promise = $bulk->reindex(
-        source       => $source,                # required
-        transform    => \&transform,            # optional
-        version_type => 'external|internal',    # optional
-    );
-
-The C<reindex()> method requires a C<$source> parameter, which provides
-the source for the documents which are to be reindexed.
-
-=head2 Reindexing from another index
-
-If the C<source> argument is a HASH ref, then the hash is passed to
-L<Search::Elasticsearch::Client::2_0::Async::Scroll/new()> to create a new scrolled search.
-
-    $bulk = $es->bulk_helper->new(
-        index   => 'new_index',
-        verbose => 1
-    );
-
-    $bulk->reindex(
-        source  => {
-            index       => 'old_index',
-            size        => 500,         # default
-            search_type => 'scan'       # default
-        }
-    )->then(
-        sub { say "Done"},
-        sub { die @_    }
-    );
-
-If a default C<index> or C<type> has been specified in the call to
-L</new()>, then it will replace the C<index> and C<type> values for
-the docs returned from the scrolled search. In the example above,
-all docs will be retrieved from C<"old_index"> and will be bulk indexed
-into C<"new_index">.
-
-=head2 Reindexing from a generic source
-
-The C<source> parameter also accepts a coderef or an anonymous sub,
-which should return one or more new documents every time it is executed.
-This allows you to pass any iterator, wrapped in an anonymous sub:
-
-    my $iter = get_iterator_from_somewhere();
-
-    $promise = $bulk->reindex(
-        source => sub { $iter->next }
-    );
-
-=head2 Transforming docs on the fly
-
-The C<transform> parameter allows you to change documents on the fly,
-using a callback.  The callback receives the document as the only argument,
-and should return the updated document, or C<undef> if the document should
-not be indexed:
-
-    $promise = $bulk->reindex(
-        source      => { index => 'old_index' },
-        transform   => sub {
-            my $doc = shift;
-
-            # don't index doc marked as valid:false
-            return undef unless $doc->{_source}{valid};
-
-            # convert $tag to @tags
-            $doc->{_source}{tags} = [ delete $doc->{_source}{tag}];
-            return $doc
-        }
-    );
-
-=head2 Reindexing from another cluster
-
-By default, L</reindex()> expects the source and destination indices
-to be in the same cluster. To pull data from one cluster and index it into
-another, you can use two separate C<$es> objects:
-
-    $es_target  = Search::Elasticsearch::Async->new( nodes => 'localhost:9200' );
-    $es_source  = Search::Elasticsearch::Async->new( nodes => 'search1:9200' );
-
-    $promise = $es_target->bulk_helper(
-        verbose => 1
-    )
-    -> reindex(
-          source => {
-              es    => $es_source,
-              index => 'my_index'
-          }
-    );
-
-=head2 Parents and routing
-
-If you are using parent-child relationships or custom C<routing> values,
-and you want to preserve these when you reindex your documents, then
-you will need to request these values specifically, as follows:
-
-    $promise = $bulk->reindex(
-        source => {
-            index   => 'old_index',
-            fields  => ['_source','_parent','_routing']
-        }
-    );
-
-=head2 Working with version numbers
-
-Every document in Elasticsearch has a current C<version> number, which
-is used for L<optimistic concurrency control|http://en.wikipedia.org/wiki/Optimistic_concurrency_control>,
-that is, to ensure that you don't overwrite changes that have been made
-by another process.
-
-All CRUD operations accept a C<version> parameter and a C<version_type>
-parameter which tells Elasticsearch that the change should only be made
-if the current document corresponds to these parameters. The
-C<version_type> parameter can have the following values:
-
-=over
-
-=item * C<internal>
-
-Use Elasticsearch version numbers.  Documents are only changed if the
-document in Elasticsearch has the B<same> C<version> number that is
-specified in the CRUD operation. After the change, the new
-version number is C<version+1>.
-
-=item * C<external>
-
-Use an external versioning system, such as timestamps or version numbers
-from an external database.  Documents are only changed if the document
-in Elasticsearch has a B<lower> C<version> number than the one
-specified in the CRUD operation. After the change, the new version
-number is C<version>.
-
-=back
-
-If you would like to reindex documents from one index to another, preserving
-the C<version> numbers from the original index, then you need the following:
-
-    $promise = $bulk->reindex(
-        source => {
-            index   => 'old_index',
-            version => 1,               # retrieve version numbers in search
-        },
-        version_type => 'external'      # use these "external" version numbers
-    );
+L<Search::Elasticsearch::Client::5_0::Direct/update()>.
 
 =head1 AUTHOR
 
